#include <LCD_I2C.h>
LCD_I2C lcd(0x27);

boolean ON = 1;
boolean OFF = 0;
unsigned long time_slow;
unsigned long time_fast;

// IO Pins

#define BUTTON_UP      6
#define BUTTON_DOWN    7
#define BUTTON_SELECT  4
#define BUTTON_BACK    5
#define PIN_ACTUATOR1  2
#define PIN_ACTUATOR2  3
#define PIN_POTI       A0

// Tastenkodierung

#define KEY_UP          (1<<0)
#define KEY_DOWN        (1<<1)
#define KEY_SELECT      (1<<2)
#define KEY_BACK        (1<<3)
#define REPEAT_MASK     (KEY_SELECT | KEY_UP | KEY_DOWN)       // repeat: key1, key2
#define REPEAT_START    50                        // after 500ms
#define REPEAT_NEXT     20                        // every 200ms

#define SLOW_PERIOD 100    // ms, Zeitraster für Menu
#define FAST_PERIOD 10     // ms, Zeitraster für Tastenentprellung und LED Steuerung

//---Menukodierung---//

#define MENU_MAIN 0
#define MENU_SUB1 1
#define MENU_SUB2 2
#define MENU_SUB3 3

volatile uint8_t key_state;                 // debounced and inverted key state:
volatile uint8_t key_press;                 // key press detect
volatile uint8_t key_rpt;                   // key long press and repeat

int poti;
int menu;
int cursor;
boolean led_active = true;

// LCD Symbol

uint8_t Cam[] = {
  B00000,
  B00000,
  B01000,
  B11111,
  B11011,
  B11111,
  B00000,
  B00000
};

void setup() {
  Serial.begin(9600);
  lcd.begin();
  lcd.backlight();
  lcd.createChar(0, Cam);
  pinMode(BUTTON_UP, INPUT_PULLUP);
  pinMode(BUTTON_DOWN, INPUT_PULLUP);
  pinMode(BUTTON_SELECT, INPUT_PULLUP);
  pinMode(BUTTON_BACK, INPUT_PULLUP);
  pinMode(PIN_ACTUATOR1, OUTPUT);
  pinMode(PIN_ACTUATOR2, OUTPUT);
  time_slow = millis();
  time_fast = time_slow;
}

void loop() {
  if ( (millis() - time_fast) >= FAST_PERIOD) {
    time_fast += FAST_PERIOD;
    entprellung();
    LED_Action();
  }
  
  if ( (millis() - time_slow) >= SLOW_PERIOD) {
    time_slow += SLOW_PERIOD;
    menu_FSM();
  }
}
